// Copyright (c) 2019, Sylabs Inc. All rights reserved.
// This software is licensed under a 3-clause BSD license. Please consult the
// LICENSE.md file distributed with the sources of this project regarding your
// rights to use or distribute this software.

package e2e

import (
	"testing"

	"github.com/sylabs/singularity/internal/pkg/test/exec"
)

func PrepRegistry(t *testing.T) {
	commands := [][]string{
		{"run", "-d", "-p", "5000:5000", "--restart=always", "--name", "registry", "registry:2"},
		{"pull", "busybox"},
		{"tag", "busybox", "localhost:5000/my-busybox"},
		{"push", "localhost:5000/my-busybox"},
	}

	for _, command := range commands {
		cmd := exec.Command("docker", command...)
		if res := cmd.Run(t); res.Error != nil {
			t.Fatalf("Command failed.\n%s", res)
		}
	}

	EnsureImage(t)
	cmd, _, err := ImagePush(t, testenv.ImagePath, "oras://localhost:5000/oras_test_sif:latest")
	if err != nil {
		t.Fatalf("while prepping registry with command %q: %v", cmd, err)
	}
}

func KillRegistry(t *testing.T) {
	commands := [][]string{
		{"kill", "registry"},
		{"rm", "registry"},
	}

	for _, command := range commands {
		cmd := exec.Command("docker", command...)
		if res := cmd.Run(t); res.Error != nil {
			t.Fatalf("Command failed.\n%s", res)
		}
	}
}
